@@ -26,7 +26,7 @@ fn is_correct_vehicle(route: &Route, target_id: &str, target_shift: usize) -> bo
 }
 
 fn is_single_belongs_to_route(ctx: &RouteContext, single: &Arc<Single>) -> bool {
-    let vehicle_id = get_vehicle_id_from_job(&single).unwrap();
+    let vehicle_id = get_vehicle_id_from_job(single).unwrap();
     let shift_index = get_shift_index(&single.dimens);
 
     is_correct_vehicle(&ctx.route, vehicle_id, shift_index)
