@@ -28,12 +28,12 @@ pub fn create_objective(
                         MinimizeDistance => core_objectives.push(TotalDistance::minimize()),
                         MinimizeDuration => core_objectives.push(TotalDuration::minimize()),
                         MinimizeTours => {
-                            constraint.add_module(Box::new(FleetUsageConstraintModule::new_minimized()));
-                            core_objectives.push(Box::new(TotalRoutes::new_minimized()))
+                            constraint.add_module(Arc::new(FleetUsageConstraintModule::new_minimized()));
+                            core_objectives.push(Arc::new(TotalRoutes::new_minimized()))
                         }
                         MaximizeTours => {
-                            constraint.add_module(Box::new(FleetUsageConstraintModule::new_maximized()));
-                            core_objectives.push(Box::new(TotalRoutes::new_maximized()))
+                            constraint.add_module(Arc::new(FleetUsageConstraintModule::new_maximized()));
+                            core_objectives.push(Arc::new(TotalRoutes::new_maximized()))
                         }
                         MaximizeValue { reduction_factor } => {
                             let (module, objective) = TotalValue::maximize(
@@ -48,7 +48,7 @@ pub fn create_objective(
                         }
                         MinimizeUnassignedJobs { breaks } => {
                             if let Some(breaks) = *breaks {
-                                core_objectives.push(Box::new(TotalUnassignedJobs::new(Arc::new(move |_, job, _| {
+                                core_objectives.push(Arc::new(TotalUnassignedJobs::new(Arc::new(move |_, job, _| {
                                     job.dimens().get_value::<String>("type").map_or(1., |job_type| {
                                         if job_type == "break" {
                                             breaks
@@ -58,7 +58,7 @@ pub fn create_objective(
                                     })
                                 }))))
                             } else {
-                                core_objectives.push(Box::new(TotalUnassignedJobs::default()))
+                                core_objectives.push(Arc::new(TotalUnassignedJobs::default()))
                             }
                         }
                         BalanceMaxLoad { options } => {
@@ -100,12 +100,12 @@ pub fn create_objective(
             let (value_module, value_objective) = get_value(max_value);
 
             constraint.add_module(value_module);
-            constraint.add_module(Box::new(FleetUsageConstraintModule::new_minimized()));
+            constraint.add_module(Arc::new(FleetUsageConstraintModule::new_minimized()));
 
             let mut objectives = vec![
                 vec![value_objective],
-                vec![Box::new(TotalUnassignedJobs::default())],
-                vec![Box::new(TotalRoutes::default())],
+                vec![Arc::new(TotalUnassignedJobs::default())],
+                vec![Arc::new(TotalRoutes::default())],
                 vec![TotalCost::minimize()],
             ];
 
@@ -125,8 +125,8 @@ pub fn create_objective(
             constraint.add_module(order_module);
 
             let mut objectives: Vec<Vec<TargetObjective>> = vec![
-                vec![Box::new(TotalUnassignedJobs::default())],
-                vec![Box::new(TotalRoutes::default())],
+                vec![Arc::new(TotalUnassignedJobs::default())],
+                vec![Arc::new(TotalRoutes::default())],
                 vec![TotalCost::minimize()],
             ];
 
@@ -137,7 +137,7 @@ pub fn create_objective(
             ObjectiveCost::new(objectives)
         }
         _ => {
-            constraint.add_module(Box::new(FleetUsageConstraintModule::new_minimized()));
+            constraint.add_module(Arc::new(FleetUsageConstraintModule::new_minimized()));
             ObjectiveCost::default()
         }
     })
