@@ -20,9 +20,7 @@ fn can_assign_interval_break_between_jobs() {
                 shifts: vec![VehicleShift {
                     breaks: Some(vec![VehicleBreak {
                         time: VehicleBreakTime::TimeOffset(vec![5., 10.]),
-                        duration: 2.0,
-                        locations: None,
-                        tag: None,
+                        places: vec![VehicleBreakPlace { duration: 2.0, location: None, tag: None }],
                     }]),
                     ..create_default_vehicle_shift()
                 }],
@@ -147,9 +145,7 @@ fn can_assign_interval_break_with_reload() {
                     dispatch: None,
                     breaks: Some(vec![VehicleBreak {
                         time: VehicleBreakTime::TimeOffset(vec![8., 12.]),
-                        duration: 2.0,
-                        locations: None,
-                        tag: None,
+                        places: vec![VehicleBreakPlace { duration: 2.0, location: None, tag: None }],
                     }]),
                     reloads: Some(vec![VehicleReload {
                         times: Some(vec![vec![format_time(0.), format_time(1000.)]]),
@@ -291,9 +287,7 @@ fn can_consider_departure_rescheduling() {
                 shifts: vec![VehicleShift {
                     breaks: Some(vec![VehicleBreak {
                         time: VehicleBreakTime::TimeOffset(vec![10., 12.]),
-                        duration: 2.0,
-                        locations: None,
-                        tag: None,
+                        places: vec![VehicleBreakPlace { duration: 2.0, location: None, tag: None }],
                     }]),
                     ..create_default_vehicle_shift()
                 }],
