@@ -21,15 +21,15 @@ fn can_use_two_breaks() {
                     breaks: Some(vec![
                         VehicleBreak {
                             time: VehicleBreakTime::TimeWindow(vec![format_time(5.), format_time(10.)]),
-                            duration: 2.0,
-                            locations: Some(vec![vec![6., 0.].to_loc()]),
-                            tag: None,
+                            places: vec![VehicleBreakPlace {
+                                duration: 2.0,
+                                location: Some(vec![6., 0.].to_loc()),
+                                tag: None,
+                            }],
                         },
                         VehicleBreak {
                             time: VehicleBreakTime::TimeWindow(vec![format_time(100.), format_time(120.)]),
-                            duration: 2.0,
-                            locations: None,
-                            tag: None,
+                            places: vec![VehicleBreakPlace { duration: 2.0, location: None, tag: None }],
                         },
                     ]),
                     ..create_default_vehicle_shift()
