@@ -7,12 +7,12 @@ use std::sync::Arc;
 use vrp_core::models::common::Profile as CoreProfile;
 use vrp_core::models::problem::{ActivityCost, SimpleActivityCost, TransportCost};
 
-pub fn create_job_place(location: Vec<f64>) -> JobPlace {
-    JobPlace { times: None, location: location.to_loc(), duration: 1. }
+pub fn create_job_place(location: Vec<f64>, tag: Option<String>) -> JobPlace {
+    JobPlace { times: None, location: location.to_loc(), duration: 1., tag }
 }
 
-pub fn create_task(location: Vec<f64>) -> JobTask {
-    JobTask { places: vec![create_job_place(location)], demand: Some(vec![1]), tag: None, order: None }
+pub fn create_task(location: Vec<f64>, tag: Option<String>) -> JobTask {
+    JobTask { places: vec![create_job_place(location, tag)], demand: Some(vec![1]), order: None }
 }
 
 pub fn create_job(id: &str) -> Job {
@@ -28,15 +28,14 @@ pub fn create_job(id: &str) -> Job {
 }
 
 pub fn create_delivery_job(id: &str, location: Vec<f64>) -> Job {
-    Job { deliveries: Some(vec![create_task(location.clone())]), ..create_job(id) }
+    Job { deliveries: Some(vec![create_task(location.clone(), None)]), ..create_job(id) }
 }
 
 pub fn create_delivery_job_with_order(id: &str, location: Vec<f64>, order: i32) -> Job {
     Job {
         deliveries: Some(vec![JobTask {
-            places: vec![create_job_place(location)],
+            places: vec![create_job_place(location, None)],
             demand: Some(vec![1]),
-            tag: None,
             order: Some(order),
         }]),
         ..create_job(id)
@@ -48,15 +47,14 @@ pub fn create_delivery_job_with_skills(id: &str, location: Vec<f64>, skills: Job
 }
 
 pub fn create_delivery_job_with_demand(id: &str, location: Vec<f64>, demand: Vec<i32>) -> Job {
-    Job { deliveries: Some(vec![JobTask { demand: Some(demand), ..create_task(location) }]), ..create_job(id) }
+    Job { deliveries: Some(vec![JobTask { demand: Some(demand), ..create_task(location, None) }]), ..create_job(id) }
 }
 
 pub fn create_delivery_job_with_duration(id: &str, location: Vec<f64>, duration: f64) -> Job {
     Job {
         deliveries: Some(vec![JobTask {
-            places: vec![JobPlace { duration, ..create_job_place(location) }],
+            places: vec![JobPlace { duration, ..create_job_place(location, None) }],
             demand: Some(vec![1]),
-            tag: None,
             order: None,
         }]),
         ..create_job(id)
@@ -66,9 +64,8 @@ pub fn create_delivery_job_with_duration(id: &str, location: Vec<f64>, duration:
 pub fn create_delivery_job_with_times(id: &str, location: Vec<f64>, times: Vec<(i32, i32)>, duration: f64) -> Job {
     Job {
         deliveries: Some(vec![JobTask {
-            places: vec![JobPlace { duration, times: convert_times(&times), ..create_job_place(location) }],
+            places: vec![JobPlace { duration, times: convert_times(&times), ..create_job_place(location, None) }],
             demand: Some(vec![1]),
-            tag: None,
             order: None,
         }]),
         ..create_job(id)
@@ -76,29 +73,29 @@ pub fn create_delivery_job_with_times(id: &str, location: Vec<f64>, times: Vec<(
 }
 
 pub fn create_delivery_job_with_value(id: &str, location: Vec<f64>, value: f64) -> Job {
-    Job { deliveries: Some(vec![create_task(location.clone())]), value: Some(value), ..create_job(id) }
+    Job { deliveries: Some(vec![create_task(location.clone(), None)]), value: Some(value), ..create_job(id) }
 }
 
 pub fn create_pickup_job(id: &str, location: Vec<f64>) -> Job {
-    Job { pickups: Some(vec![create_task(location.clone())]), ..create_job(id) }
+    Job { pickups: Some(vec![create_task(location.clone(), None)]), ..create_job(id) }
 }
 
 pub fn create_pickup_job_with_demand(id: &str, location: Vec<f64>, demand: Vec<i32>) -> Job {
-    Job { pickups: Some(vec![JobTask { demand: Some(demand), ..create_task(location) }]), ..create_job(id) }
+    Job { pickups: Some(vec![JobTask { demand: Some(demand), ..create_task(location, None) }]), ..create_job(id) }
 }
 
 pub fn create_replacement_job(id: &str, location: Vec<f64>) -> Job {
-    Job { replacements: Some(vec![create_task(location.clone())]), ..create_job(id) }
+    Job { replacements: Some(vec![create_task(location.clone(), None)]), ..create_job(id) }
 }
 
 pub fn create_service_job(id: &str, location: Vec<f64>) -> Job {
-    Job { services: Some(vec![JobTask { demand: None, ..create_task(location.clone()) }]), ..create_job(id) }
+    Job { services: Some(vec![JobTask { demand: None, ..create_task(location.clone(), None) }]), ..create_job(id) }
 }
 
 pub fn create_pickup_delivery_job(id: &str, pickup_location: Vec<f64>, delivery_location: Vec<f64>) -> Job {
     Job {
-        pickups: Some(vec![JobTask { tag: Some("p1".to_string()), ..create_task(pickup_location.clone()) }]),
-        deliveries: Some(vec![JobTask { tag: Some("d1".to_string()), ..create_task(delivery_location.clone()) }]),
+        pickups: Some(vec![create_task(pickup_location.clone(), Some("p1".to_string()))]),
+        deliveries: Some(vec![create_task(delivery_location.clone(), Some("d1".to_string()))]),
         ..create_job(id)
     }
 }
@@ -114,20 +111,18 @@ pub fn create_pickup_delivery_job_with_params(
             places: vec![JobPlace {
                 duration: pickup.1,
                 times: convert_times(&pickup.2),
-                ..create_job_place(pickup.0.clone())
+                ..create_job_place(pickup.0.clone(), Some("p1".to_string()))
             }],
             demand: Some(demand.clone()),
-            tag: Some("p1".to_string()),
             order: None,
         }]),
         deliveries: Some(vec![JobTask {
             places: vec![JobPlace {
                 duration: delivery.1,
                 times: convert_times(&delivery.2),
-                ..create_job_place(delivery.0.clone())
+                ..create_job_place(delivery.0.clone(), Some("d1".to_string()))
             }],
             demand: Some(demand.clone()),
-            tag: Some("d1".to_string()),
             order: None,
         }]),
 
@@ -138,9 +133,8 @@ pub fn create_pickup_delivery_job_with_params(
 pub fn create_delivery_job_with_index(id: &str, index: usize) -> Job {
     Job {
         deliveries: Some(vec![JobTask {
-            places: vec![JobPlace { times: None, location: Location::Reference { index }, duration: 1. }],
+            places: vec![JobPlace { times: None, location: Location::Reference { index }, duration: 1., tag: None }],
             demand: Some(vec![1]),
-            tag: None,
             order: None,
         }]),
         ..create_job(id)
@@ -157,9 +151,11 @@ pub fn create_multi_job(
             .into_iter()
             .enumerate()
             .map(|(i, (location, duration, demand))| JobTask {
-                places: vec![JobPlace { duration, ..create_job_place(vec![location.0, location.1]) }],
+                places: vec![JobPlace {
+                    duration,
+                    ..create_job_place(vec![location.0, location.1], Some(format!("{}{}", prefix, i + 1)))
+                }],
                 demand: Some(demand),
-                tag: Some(format!("{}{}", prefix, i + 1)),
                 order: None,
             })
             .collect::<Vec<_>>();
