@@ -77,9 +77,9 @@ fn can_read_complex_problem() {
                             ]),
                             location: vec![52.48325, 13.4436].to_loc(),
                             duration: 100.0,
+                            tag: Some("my_delivery".to_string()),
                         }],
                         demand: Some(vec![0, 1]),
-                        tag: Some("my_delivery".to_string()),
                         order: None,
                     }]),
                     skills: Some(all_of_skills(vec!["unique".to_string()])),
@@ -94,9 +94,9 @@ fn can_read_complex_problem() {
                             ]]),
                             location: vec![52.48300, 13.4420].to_loc(),
                             duration: 110.0,
+                            tag: None,
                         }],
                         demand: Some(vec![2]),
-                        tag: None,
                         order: None,
                     }]),
                     deliveries: Some(vec![JobTask {
@@ -107,9 +107,9 @@ fn can_read_complex_problem() {
                             ]]),
                             location: vec![52.48325, 13.4436].to_loc(),
                             duration: 120.0,
+                            tag: None,
                         }],
                         demand: Some(vec![2]),
-                        tag: None,
                         order: None,
                     }]),
                     ..create_job("pickup_delivery_job")
@@ -123,9 +123,9 @@ fn can_read_complex_problem() {
                             ]]),
                             location: vec![52.48321, 13.4438].to_loc(),
                             duration: 90.0,
+                            tag: None,
                         }],
                         demand: Some(vec![3]),
-                        tag: None,
                         order: None,
                     }]),
                     skills: Some(all_of_skills(vec!["unique2".to_string()])),
@@ -157,9 +157,11 @@ fn can_read_complex_problem() {
                             "1970-01-01T00:00:10Z".to_string(),
                             "1970-01-01T00:01:20Z".to_string(),
                         ]),
-                        duration: 100.0,
-                        locations: Some(vec![vec![52.48315, 13.4330].to_loc()]),
-                        tag: None,
+                        places: vec![VehicleBreakPlace {
+                            duration: 100.0,
+                            location: Some(vec![52.48315, 13.4330].to_loc()),
+                            tag: None,
+                        }],
                     }]),
                     reloads: None,
                 }],
